# rs3clans.py
A Python 3 module wrapper for RuneScape 3 Clan's API

Current Version: 0.4.4

***

## Setup:

```bash
python -m pip install rs3clans
```

***

### Examples:

* Go into the examples file for examples on usage of the module.

### Usage:

* Import:

```python3
# I would personally recommend importing as a smaller name (e.g.: import rs3clans as rs3)
import rs3clans
```

- Since i have rewritten the entire module, i still haven't remade the docs for it. Read the comments in the source code instead. There are a few examples of usage in it as well, just run it and have a look. Also look into the 'tests' folder for some examples.